function [rmse,spread] = rmse_spread(xt,xmean,Xens,anawin)
% [rmse,spread] = rmse_spread(xt,xmean,Xens,anawin)
% This function computes the rmse of the background (or analysis) mean with
% respect to the true run, as well as the spread of the background (or
% analysis) ensemble. 
% Input:        - xt, the true run of the model [length time, N variables]
%               - xmean, the background or analysis mean [length time, N variables]
%               - Xens, the background or analysis ensemble [length time, N variables, M ensemble members]
%               - anawin, the analysis window lenght, when assimilation occurs every time we observe then anawin = freqobs



[la,N,M] = size(Xens);
[la,N] = size(xt);

% select only the values at the time of assimilation
ind = (1:anawin:la)';
mse = mean((xt(ind,:)-xmean(ind,:)).^2,2);
rmse = sqrt(mse);
rmse = rmse(1:length(rmse),:);

if ~isempty(Xens)
 spread = var(Xens(ind,:,:),0,3);
 spread = mean(spread,2);
 
 spread = spread(isfinite(spread));
 spread = sqrt(spread);
 spread = spread(1:length(spread),:);
else
 spread = 0;
end

end









